******
Citing
******

.. rst-class:: lead

    If you use COMPAS RRC in your work, please cite it as below.

::

    @misc{compas-rrc,
        title  = {{COMPAS RRC}: Online control for ABB robots over a simple-to-use Python interface.},
        author = {Fleischmann, Philippe and Casas, Gonzalo and Lyrenmann, Michael},
        note   = {https://compas-rrc.github.io/compas_rrc},
        month  = {7},
        year   = {2020},
        doi    = {10.5281/zenodo.4639418},
        url    = {https://doi.org/10.5281/zenodo.4639418},
    }
